@@ -1,21 +1,10 @@
-/*******************************************************************
-* kfindtreeview.cpp
-* Copyright 2009    Dario Andres Rodriguez <andresbajotierra@gmail.com>
-*
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License as
-* published by the Free Software Foundation; either version 2 of
-* the License, or (at your option) any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*
-******************************************************************/
+/*
+    kfindtreeview.cpp
+    SPDX-FileCopyrightText: 2009 Dario Andres Rodriguez <andresbajotierra@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+
+*/
 
 #include "kfindtreeview.h"
 #include "kfinddlg.h"
@@ -349,7 +338,7 @@ KFindTreeView::KFindTreeView(QWidget *parent, KfindDlg *findDialog)
 
     QAction *del = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("&Delete"), this);
     connect(del, &QAction::triggered, this, &KFindTreeView::deleteSelectedFiles);
-    m_actionCollection->setDefaultShortcut(del, Qt::SHIFT + Qt::Key_Delete);
+    m_actionCollection->setDefaultShortcut(del, Qt::SHIFT | Qt::Key_Delete);
 
     QAction *trash = new QAction(QIcon::fromTheme(QStringLiteral("user-trash")), i18n("&Move to Trash"), this);
     connect(trash, &QAction::triggered, this, &KFindTreeView::moveToTrashSelectedFiles);
